@@ -15,7 +15,7 @@
 namespace validation_layer
 {
     ze_result_t
-    ZETHandleLifetimeValidation::zetModuleGetDebugInfo(
+    ZETHandleLifetimeValidation::zetModuleGetDebugInfoPrologue(
         zet_module_handle_t hModule,                    ///< [in] handle of the module
         zet_module_debug_info_format_t format,          ///< [in] debug info format requested
         size_t* pSize,                                  ///< [in,out] size of debug info in bytes
@@ -29,7 +29,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDeviceGetDebugProperties(
+    ZETHandleLifetimeValidation::zetDeviceGetDebugPropertiesPrologue(
         zet_device_handle_t hDevice,                    ///< [in] device handle
         zet_device_debug_properties_t* pDebugProperties ///< [in,out] query result for debug properties
         )
@@ -41,7 +41,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugAttach(
+    ZETHandleLifetimeValidation::zetDebugAttachPrologue(
         zet_device_handle_t hDevice,                    ///< [in] device handle
         const zet_debug_config_t* config,               ///< [in] the debug configuration
         zet_debug_session_handle_t* phDebug             ///< [out] debug session handle
@@ -54,7 +54,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugDetach(
+    ZETHandleLifetimeValidation::zetDebugDetachPrologue(
         zet_debug_session_handle_t hDebug               ///< [in][release] debug session handle
         )
     { 
@@ -65,7 +65,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugReadEvent(
+    ZETHandleLifetimeValidation::zetDebugReadEventPrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         uint64_t timeout,                               ///< [in] if non-zero, then indicates the maximum time (in milliseconds) to
                                                         ///< yield before returning ::ZE_RESULT_SUCCESS or ::ZE_RESULT_NOT_READY;
@@ -84,7 +84,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugAcknowledgeEvent(
+    ZETHandleLifetimeValidation::zetDebugAcknowledgeEventPrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         const zet_debug_event_t* event                  ///< [in] a pointer to a ::zet_debug_event_t.
         )
@@ -96,7 +96,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugInterrupt(
+    ZETHandleLifetimeValidation::zetDebugInterruptPrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         ze_device_thread_t thread                       ///< [in] the thread to interrupt
         )
@@ -108,7 +108,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugResume(
+    ZETHandleLifetimeValidation::zetDebugResumePrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         ze_device_thread_t thread                       ///< [in] the thread to resume
         )
@@ -120,7 +120,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugReadMemory(
+    ZETHandleLifetimeValidation::zetDebugReadMemoryPrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         ze_device_thread_t thread,                      ///< [in] the thread identifier.
         const zet_debug_memory_space_desc_t* desc,      ///< [in] memory space descriptor
@@ -135,7 +135,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugWriteMemory(
+    ZETHandleLifetimeValidation::zetDebugWriteMemoryPrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         ze_device_thread_t thread,                      ///< [in] the thread identifier.
         const zet_debug_memory_space_desc_t* desc,      ///< [in] memory space descriptor
@@ -150,7 +150,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugGetRegisterSetProperties(
+    ZETHandleLifetimeValidation::zetDebugGetRegisterSetPropertiesPrologue(
         zet_device_handle_t hDevice,                    ///< [in] device handle
         uint32_t* pCount,                               ///< [in,out] pointer to the number of register set properties.
                                                         ///< if count is zero, then the driver shall update the value with the
@@ -171,7 +171,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugGetThreadRegisterSetProperties(
+    ZETHandleLifetimeValidation::zetDebugGetThreadRegisterSetPropertiesPrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         ze_device_thread_t thread,                      ///< [in] the thread identifier specifying a single stopped thread
         uint32_t* pCount,                               ///< [in,out] pointer to the number of register set properties.
@@ -193,7 +193,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugReadRegisters(
+    ZETHandleLifetimeValidation::zetDebugReadRegistersPrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         ze_device_thread_t thread,                      ///< [in] the thread identifier
         uint32_t type,                                  ///< [in] register set type
@@ -213,7 +213,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetDebugWriteRegisters(
+    ZETHandleLifetimeValidation::zetDebugWriteRegistersPrologue(
         zet_debug_session_handle_t hDebug,              ///< [in] debug session handle
         ze_device_thread_t thread,                      ///< [in] the thread identifier
         uint32_t type,                                  ///< [in] register set type
@@ -233,7 +233,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupGet(
+    ZETHandleLifetimeValidation::zetMetricGroupGetPrologue(
         zet_device_handle_t hDevice,                    ///< [in] handle of the device
         uint32_t* pCount,                               ///< [in,out] pointer to the number of metric groups.
                                                         ///< if count is zero, then the driver shall update the value with the
@@ -253,7 +253,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupGetProperties(
+    ZETHandleLifetimeValidation::zetMetricGroupGetPropertiesPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
         zet_metric_group_properties_t* pProperties      ///< [in,out] metric group properties
         )
@@ -265,7 +265,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupCalculateMetricValues(
+    ZETHandleLifetimeValidation::zetMetricGroupCalculateMetricValuesPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
         zet_metric_group_calculation_type_t type,       ///< [in] calculation type to be applied on raw data
         size_t rawDataSize,                             ///< [in] size in bytes of raw data buffer
@@ -288,7 +288,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGet(
+    ZETHandleLifetimeValidation::zetMetricGetPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
         uint32_t* pCount,                               ///< [in,out] pointer to the number of metrics.
                                                         ///< if count is zero, then the driver shall update the value with the
@@ -307,7 +307,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGetProperties(
+    ZETHandleLifetimeValidation::zetMetricGetPropertiesPrologue(
         zet_metric_handle_t hMetric,                    ///< [in] handle of the metric
         zet_metric_properties_t* pProperties            ///< [in,out] metric properties
         )
@@ -319,7 +319,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetContextActivateMetricGroups(
+    ZETHandleLifetimeValidation::zetContextActivateMetricGroupsPrologue(
         zet_context_handle_t hContext,                  ///< [in] handle of the context object
         zet_device_handle_t hDevice,                    ///< [in] handle of the device
         uint32_t count,                                 ///< [in] metric group count to activate; must be 0 if `nullptr ==
@@ -345,7 +345,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricStreamerOpen(
+    ZETHandleLifetimeValidation::zetMetricStreamerOpenPrologue(
         zet_context_handle_t hContext,                  ///< [in] handle of the context object
         zet_device_handle_t hDevice,                    ///< [in] handle of the device
         zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
@@ -370,7 +370,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetCommandListAppendMetricStreamerMarker(
+    ZETHandleLifetimeValidation::zetCommandListAppendMetricStreamerMarkerPrologue(
         zet_command_list_handle_t hCommandList,         ///< [in] handle of the command list
         zet_metric_streamer_handle_t hMetricStreamer,   ///< [in] handle of the metric streamer
         uint32_t value                                  ///< [in] streamer marker value
@@ -389,7 +389,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricStreamerClose(
+    ZETHandleLifetimeValidation::zetMetricStreamerClosePrologue(
         zet_metric_streamer_handle_t hMetricStreamer    ///< [in][release] handle of the metric streamer
         )
     { 
@@ -400,7 +400,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricStreamerReadData(
+    ZETHandleLifetimeValidation::zetMetricStreamerReadDataPrologue(
         zet_metric_streamer_handle_t hMetricStreamer,   ///< [in] handle of the metric streamer
         uint32_t maxReportCount,                        ///< [in] the maximum number of reports the application wants to receive.
                                                         ///< if `UINT32_MAX`, then function will retrieve all reports available
@@ -422,7 +422,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricQueryPoolCreate(
+    ZETHandleLifetimeValidation::zetMetricQueryPoolCreatePrologue(
         zet_context_handle_t hContext,                  ///< [in] handle of the context object
         zet_device_handle_t hDevice,                    ///< [in] handle of the device
         zet_metric_group_handle_t hMetricGroup,         ///< [in] metric group associated with the query object.
@@ -443,7 +443,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricQueryPoolDestroy(
+    ZETHandleLifetimeValidation::zetMetricQueryPoolDestroyPrologue(
         zet_metric_query_pool_handle_t hMetricQueryPool ///< [in][release] handle of the metric query pool
         )
     { 
@@ -460,7 +460,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricQueryCreate(
+    ZETHandleLifetimeValidation::zetMetricQueryCreatePrologue(
         zet_metric_query_pool_handle_t hMetricQueryPool,///< [in] handle of the metric query pool
         uint32_t index,                                 ///< [in] index of the query within the pool
         zet_metric_query_handle_t* phMetricQuery        ///< [out] handle of metric query
@@ -473,7 +473,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricQueryDestroy(
+    ZETHandleLifetimeValidation::zetMetricQueryDestroyPrologue(
         zet_metric_query_handle_t hMetricQuery          ///< [in][release] handle of metric query
         )
     { 
@@ -490,7 +490,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricQueryReset(
+    ZETHandleLifetimeValidation::zetMetricQueryResetPrologue(
         zet_metric_query_handle_t hMetricQuery          ///< [in] handle of metric query
         )
     { 
@@ -501,7 +501,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetCommandListAppendMetricQueryBegin(
+    ZETHandleLifetimeValidation::zetCommandListAppendMetricQueryBeginPrologue(
         zet_command_list_handle_t hCommandList,         ///< [in] handle of the command list
         zet_metric_query_handle_t hMetricQuery          ///< [in] handle of the metric query
         )
@@ -519,7 +519,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetCommandListAppendMetricQueryEnd(
+    ZETHandleLifetimeValidation::zetCommandListAppendMetricQueryEndPrologue(
         zet_command_list_handle_t hCommandList,         ///< [in] handle of the command list
         zet_metric_query_handle_t hMetricQuery,         ///< [in] handle of the metric query
         ze_event_handle_t hSignalEvent,                 ///< [in][optional] handle of the event to signal on completion
@@ -543,7 +543,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetCommandListAppendMetricMemoryBarrier(
+    ZETHandleLifetimeValidation::zetCommandListAppendMetricMemoryBarrierPrologue(
         zet_command_list_handle_t hCommandList          ///< [in] handle of the command list
         )
     { 
@@ -557,7 +557,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricQueryGetData(
+    ZETHandleLifetimeValidation::zetMetricQueryGetDataPrologue(
         zet_metric_query_handle_t hMetricQuery,         ///< [in] handle of the metric query
         size_t* pRawDataSize,                           ///< [in,out] pointer to size in bytes of raw data requested to read.
                                                         ///< if size is zero, then the driver will update the value with the total
@@ -577,7 +577,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetKernelGetProfileInfo(
+    ZETHandleLifetimeValidation::zetKernelGetProfileInfoPrologue(
         zet_kernel_handle_t hKernel,                    ///< [in] handle to kernel
         zet_profile_properties_t* pProfileProperties    ///< [out] pointer to profile properties
         )
@@ -589,7 +589,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetTracerExpCreate(
+    ZETHandleLifetimeValidation::zetTracerExpCreatePrologue(
         zet_context_handle_t hContext,                  ///< [in] handle of the context object
         const zet_tracer_exp_desc_t* desc,              ///< [in] pointer to tracer descriptor
         zet_tracer_exp_handle_t* phTracer               ///< [out] pointer to handle of tracer object created
@@ -602,7 +602,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetTracerExpDestroy(
+    ZETHandleLifetimeValidation::zetTracerExpDestroyPrologue(
         zet_tracer_exp_handle_t hTracer                 ///< [in][release] handle of tracer object to destroy
         )
     { 
@@ -619,7 +619,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetTracerExpSetPrologues(
+    ZETHandleLifetimeValidation::zetTracerExpSetProloguesPrologue(
         zet_tracer_exp_handle_t hTracer,                ///< [in] handle of the tracer
         zet_core_callbacks_t* pCoreCbs                  ///< [in] pointer to table of 'core' callback function pointers
         )
@@ -631,7 +631,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetTracerExpSetEpilogues(
+    ZETHandleLifetimeValidation::zetTracerExpSetEpiloguesPrologue(
         zet_tracer_exp_handle_t hTracer,                ///< [in] handle of the tracer
         zet_core_callbacks_t* pCoreCbs                  ///< [in] pointer to table of 'core' callback function pointers
         )
@@ -643,7 +643,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetTracerExpSetEnabled(
+    ZETHandleLifetimeValidation::zetTracerExpSetEnabledPrologue(
         zet_tracer_exp_handle_t hTracer,                ///< [in] handle of the tracer
         ze_bool_t enable                                ///< [in] enable the tracer if true; disable if false
         )
@@ -655,7 +655,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupCalculateMultipleMetricValuesExp(
+    ZETHandleLifetimeValidation::zetMetricGroupCalculateMultipleMetricValuesExpPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
         zet_metric_group_calculation_type_t type,       ///< [in] calculation type to be applied on raw data
         size_t rawDataSize,                             ///< [in] size in bytes of raw data buffer
@@ -688,7 +688,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupGetGlobalTimestampsExp(
+    ZETHandleLifetimeValidation::zetMetricGroupGetGlobalTimestampsExpPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
         ze_bool_t synchronizedWithHost,                 ///< [in] Returns the timestamps synchronized to the host or the device.
         uint64_t* globalTimestamp,                      ///< [out] Device timestamp.
@@ -702,7 +702,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupGetExportDataExp(
+    ZETHandleLifetimeValidation::zetMetricGroupGetExportDataExpPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
         const uint8_t* pRawData,                        ///< [in] buffer of raw data
         size_t rawDataSize,                             ///< [in] size in bytes of raw data buffer
@@ -721,7 +721,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupCalculateMetricExportDataExp(
+    ZETHandleLifetimeValidation::zetMetricGroupCalculateMetricExportDataExpPrologue(
         ze_driver_handle_t hDriver,                     ///< [in] handle of the driver instance
         zet_metric_group_calculation_type_t type,       ///< [in] calculation type to be applied on raw data
         size_t exportDataSize,                          ///< [in] size in bytes of exported data buffer
@@ -755,7 +755,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricProgrammableGetExp(
+    ZETHandleLifetimeValidation::zetMetricProgrammableGetExpPrologue(
         zet_device_handle_t hDevice,                    ///< [in] handle of the device
         uint32_t* pCount,                               ///< [in,out] pointer to the number of metric programmable handles.
                                                         ///< if count is zero, then the driver shall update the value with the
@@ -775,7 +775,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricProgrammableGetPropertiesExp(
+    ZETHandleLifetimeValidation::zetMetricProgrammableGetPropertiesExpPrologue(
         zet_metric_programmable_exp_handle_t hMetricProgrammable,   ///< [in] handle of the metric programmable
         zet_metric_programmable_exp_properties_t* pProperties   ///< [in,out] properties of the metric programmable
         )
@@ -787,7 +787,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricProgrammableGetParamInfoExp(
+    ZETHandleLifetimeValidation::zetMetricProgrammableGetParamInfoExpPrologue(
         zet_metric_programmable_exp_handle_t hMetricProgrammable,   ///< [in] handle of the metric programmable
         uint32_t* pParameterCount,                      ///< [in,out] count of the parameters to retrieve parameter info.
                                                         ///< if value pParameterCount is greater than count of parameters
@@ -806,7 +806,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricProgrammableGetParamValueInfoExp(
+    ZETHandleLifetimeValidation::zetMetricProgrammableGetParamValueInfoExpPrologue(
         zet_metric_programmable_exp_handle_t hMetricProgrammable,   ///< [in] handle of the metric programmable
         uint32_t parameterOrdinal,                      ///< [in] ordinal of the parameter in the metric programmable
         uint32_t* pValueInfoCount,                      ///< [in,out] count of parameter value information to retrieve.
@@ -826,7 +826,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricCreateFromProgrammableExp(
+    ZETHandleLifetimeValidation::zetMetricCreateFromProgrammableExpPrologue(
         zet_metric_programmable_exp_handle_t hMetricProgrammable,   ///< [in] handle of the metric programmable
         zet_metric_programmable_param_value_exp_t* pParameterValues,///< [in] list of parameter values to be set.
         uint32_t parameterCount,                        ///< [in] Count of parameters to set.
@@ -853,7 +853,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupCreateExp(
+    ZETHandleLifetimeValidation::zetMetricGroupCreateExpPrologue(
         zet_device_handle_t hDevice,                    ///< [in] handle of the device
         const char* pName,                              ///< [in] pointer to metric group name. Must point to a null-terminated
                                                         ///< character array no longer than ::ZET_MAX_METRIC_GROUP_NAME.
@@ -871,7 +871,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupAddMetricExp(
+    ZETHandleLifetimeValidation::zetMetricGroupAddMetricExpPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] Handle of the metric group
         zet_metric_handle_t hMetric,                    ///< [in] Metric to be added to the group.
         size_t * pErrorStringSize,                      ///< [in,out][optional] Size of the error string to query, if an error was
@@ -893,7 +893,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupRemoveMetricExp(
+    ZETHandleLifetimeValidation::zetMetricGroupRemoveMetricExpPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] Handle of the metric group
         zet_metric_handle_t hMetric                     ///< [in] Metric handle to be removed from the metric group.
         )
@@ -908,7 +908,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupCloseExp(
+    ZETHandleLifetimeValidation::zetMetricGroupCloseExpPrologue(
         zet_metric_group_handle_t hMetricGroup          ///< [in] Handle of the metric group
         )
     { 
@@ -919,7 +919,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricGroupDestroyExp(
+    ZETHandleLifetimeValidation::zetMetricGroupDestroyExpPrologue(
         zet_metric_group_handle_t hMetricGroup          ///< [in] Handle of the metric group to destroy
         )
     { 
@@ -930,7 +930,7 @@ namespace validation_layer
         return ZE_RESULT_SUCCESS;
     }
     ze_result_t
-    ZETHandleLifetimeValidation::zetMetricDestroyExp(
+    ZETHandleLifetimeValidation::zetMetricDestroyExpPrologue(
         zet_metric_handle_t hMetric                     ///< [in] Handle of the metric to destroy
         )
     { 
